<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv_SE">
<context>
    <name>CreateFieldDialog</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1142"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1155"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1165"/>
        <source>String</source>
        <translation>Sträng</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1166"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1167"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1168"/>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1169"/>
        <source>Phone Number</source>
        <translation>Telefonnummer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1170"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1171"/>
        <source>URL</source>
        <translation>Webbadress</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1176"/>
        <source>Order</source>
        <translation>Ordningstal</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="82"/>
        <source>Copy of </source>
        <translation>Kopia av </translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="129"/>
        <location filename="../../DetailedWindow.cpp" line="352"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="131"/>
        <location filename="../../DetailedWindow.cpp" line="798"/>
        <location filename="../../DetailedWindow.cpp" line="811"/>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="132"/>
        <source>Change Face Pict.</source>
        <translation>Byt framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="133"/>
        <source>Mirror Face Pict.</source>
        <translation>Spegla framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="134"/>
        <source>Change Back Pict.</source>
        <translation>Byt baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="135"/>
        <source>Mirror Back Pict.</source>
        <translation>Spegla baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="136"/>
        <source>Delete Face Pict.</source>
        <translation>Radera framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="137"/>
        <source>Delete Back Pict.</source>
        <translation>Radera baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="138"/>
        <source>Modify fields</source>
        <translation>Ändra fält</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="146"/>
        <source>New Card</source>
        <translation>Nytt kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="147"/>
        <source>Edit Card</source>
        <translation>Redigera kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="148"/>
        <source>New Card like this</source>
        <translation>Nytt likadant kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="149"/>
        <source>Duplicate Card</source>
        <translation>Duplicera kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="150"/>
        <source>Export Face Pict.</source>
        <translation>Exportera framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="151"/>
        <source>Export Back Pict.</source>
        <translation>Exportera baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="178"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="189"/>
        <source>Group Name</source>
        <translation>Gruppnamn</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="207"/>
        <source>Membership Info</source>
        <translation>Medlemskap</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="208"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="209"/>
        <source>Credit Card</source>
        <translation>Kreditkort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="210"/>
        <source>Bank Account</source>
        <translation>Bankkonto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="211"/>
        <source>Health Numbers</source>
        <translation>Hälsokort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="212"/>
        <source>Passport Info</source>
        <translation>Pass</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="213"/>
        <source>Note Card</source>
        <translation>Övrigt kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="214"/>
        <source>Car Info</source>
        <translation>Bil</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="215"/>
        <source>Cellular Phone</source>
        <translation>Mobiltelefon</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="216"/>
        <source>Serial Number Software</source>
        <translation>Serienummer (mjukvara)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="217"/>
        <source>Serial Number Hardware</source>
        <translation>Serienummer (hårdvara)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="218"/>
        <source>Web site</source>
        <translation>Webbadress</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="219"/>
        <source>ID Card</source>
        <translation>ID-kort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="220"/>
        <source>Social Security Number</source>
        <translation>Socialskyddssignum</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="221"/>
        <source>Email Account</source>
        <translation>E-postkonto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="222"/>
        <source>Driver&apos;s License</source>
        <translation>Körkort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="223"/>
        <source>Others</source>
        <translation>Annat</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="227"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="533"/>
        <location filename="../../DetailedWindow.cpp" line="579"/>
        <source>Click to see</source>
        <translation>Klicka för att visa</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="632"/>
        <source>Card description is missing</source>
        <translation>Beskrivning saknas</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="642"/>
        <source>Type card is missing</source>
        <translation>Korttyp saknas</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="796"/>
        <location filename="../../DetailedWindow.cpp" line="809"/>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="797"/>
        <location filename="../../DetailedWindow.cpp" line="810"/>
        <source>Mirror</source>
        <translation>Spegla</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="801"/>
        <source>Export Face</source>
        <translation>Exportera framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="814"/>
        <source>Export Back</source>
        <translation>Exportera baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="835"/>
        <source>Choose card face image file</source>
        <translation>Välj bildfil för framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="837"/>
        <location filename="../../DetailedWindow.cpp" line="979"/>
        <source>Images (*.png);;</source>
        <translation>Bilder PNG (*.png)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="850"/>
        <source>Choose card face image</source>
        <translation>Välj bild för framsida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="852"/>
        <location filename="../../DetailedWindow.cpp" line="995"/>
        <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
        <translation>Bilder (*.png *.jpg *.gif *.jpeg)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="977"/>
        <source>Choose card back image file</source>
        <translation>Välj bildfil för baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="993"/>
        <source>Choose card back image</source>
        <translation>Välj bild för baksida</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1052"/>
        <source>Are you sure you want to discard changes?</source>
        <translation>Är du säker på att du vill förkasta alla ändringar?</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../LoginDialog.cpp" line="97"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="105"/>
        <source>Clear</source>
        <translation>Töm</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="149"/>
        <source>About</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="157"/>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="165"/>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>About Wallet</source>
        <translation>Om Wallet</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="243"/>
        <source>Password is required</source>
        <translation>Lösenord krävs</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="260"/>
        <source>For verification, please, enter your password again</source>
        <translation>Vänligen ange lösenordet igen för bekräftelse</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="273"/>
        <source>Invalid password, please enter again</source>
        <translation>Fel lösenord, vänligen försök igen</translation>
    </message>
</context>
<context>
    <name>RenameGroupDialog</name>
    <message>
        <location filename="../../eWallet.cpp" line="51"/>
        <source>Save &amp;&amp; Close</source>
        <translation>Spara &amp;&amp; Stäng</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="64"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
</context>
<context>
    <name>eWallet</name>
    <message>
        <location filename="../../eWallet.cpp" line="446"/>
        <source>Are you sure you want to remove all your data? You will lost all your data</source>
        <translation>Är du säker på att du vill radera hela databasen? All sparad information kommer att tas bort.</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="471"/>
        <source>Wrong password</source>
        <translation>Fel lösenord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="368"/>
        <location filename="../../eWallet.cpp" line="820"/>
        <source>&lt;All&gt;</source>
        <translation>&lt;Allt&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="387"/>
        <location filename="../../eWallet.cpp" line="829"/>
        <source>&lt;No Group&gt;</source>
        <translation>&lt;Ingen grupp&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="531"/>
        <source>Organization</source>
        <translation>Organisation</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="532"/>
        <location filename="../../eWallet.cpp" line="553"/>
        <location filename="../../eWallet.cpp" line="603"/>
        <source>Phone Number</source>
        <translation>Telefonnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="533"/>
        <location filename="../../eWallet.cpp" line="567"/>
        <source>Other Information</source>
        <translation>Övrigt</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="534"/>
        <location filename="../../eWallet.cpp" line="543"/>
        <location filename="../../eWallet.cpp" line="645"/>
        <source>User Name</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="535"/>
        <location filename="../../eWallet.cpp" line="544"/>
        <location filename="../../eWallet.cpp" line="571"/>
        <location filename="../../eWallet.cpp" line="602"/>
        <location filename="../../eWallet.cpp" line="631"/>
        <location filename="../../eWallet.cpp" line="642"/>
        <location filename="../../eWallet.cpp" line="646"/>
        <location filename="../../eWallet.cpp" line="655"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="536"/>
        <source>Organization club</source>
        <translation>Klubb</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="537"/>
        <location filename="../../eWallet.cpp" line="570"/>
        <location filename="../../eWallet.cpp" line="636"/>
        <source>ID Number</source>
        <translation>ID-nummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="538"/>
        <location filename="../../eWallet.cpp" line="545"/>
        <location filename="../../eWallet.cpp" line="610"/>
        <location filename="../../eWallet.cpp" line="629"/>
        <location filename="../../eWallet.cpp" line="654"/>
        <source>URL</source>
        <translation>Webbadress</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="539"/>
        <location filename="../../eWallet.cpp" line="559"/>
        <location filename="../../eWallet.cpp" line="573"/>
        <location filename="../../eWallet.cpp" line="648"/>
        <location filename="../../eWallet.cpp" line="658"/>
        <source>Card Notes</source>
        <translation>Anteckningar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="542"/>
        <location filename="../../eWallet.cpp" line="647"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="548"/>
        <source>Credit Card Type</source>
        <translation>Typ av kreditkort</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="549"/>
        <source>Card Provider</source>
        <translation>Kortutgivare</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="550"/>
        <source>Card Number</source>
        <translation>Kortnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="551"/>
        <location filename="../../eWallet.cpp" line="556"/>
        <location filename="../../eWallet.cpp" line="653"/>
        <source>Expiration Date</source>
        <translation>Sista giltighetsdag</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="552"/>
        <source>Name on Card</source>
        <translation>Kortinnehavare</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="554"/>
        <location filename="../../eWallet.cpp" line="565"/>
        <source>PIN</source>
        <translation>PIN-kod</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="555"/>
        <source>Start Date</source>
        <translation>Startdatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="557"/>
        <source>Detail</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="558"/>
        <source>3-digit CVC#</source>
        <translation>Tresiffrig CVC#</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="562"/>
        <source>Bank Name</source>
        <translation>Bank</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="563"/>
        <source>Account Number</source>
        <translation>Kontonummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="564"/>
        <source>Telephone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="566"/>
        <source>SWIFT Code</source>
        <translation>SWIFT-kod</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="572"/>
        <location filename="../../eWallet.cpp" line="637"/>
        <source>Card Title</source>
        <translation>Kortets titel</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="576"/>
        <source>Passport No</source>
        <translation>Pass nr.</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="577"/>
        <source>Surname</source>
        <translation>Efternamn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="578"/>
        <source>Given names</source>
        <translation>Förnamn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="579"/>
        <source>Date of birth</source>
        <translation>Födelsedatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="580"/>
        <source>Date of issue</source>
        <translation>Utfärdat</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="581"/>
        <source>Date of expiration</source>
        <translation>Sista giltighetsdag</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="582"/>
        <source>Authority</source>
        <translation>Myndighet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="585"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="588"/>
        <location filename="../../eWallet.cpp" line="592"/>
        <source>Model</source>
        <translation>Modell</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="589"/>
        <source>Vehicle Number</source>
        <translation>Fordonsnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="593"/>
        <source>Brand</source>
        <translation>Varumärke</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="594"/>
        <source>IMEI#</source>
        <translation>IMEI-nummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="595"/>
        <source>Firmware code</source>
        <translation>Firmware-kod</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="596"/>
        <source>Purchased</source>
        <translation>Inköpsdatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="597"/>
        <source>Pin1</source>
        <translation>PIN-kod 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="598"/>
        <source>Pin2</source>
        <translation>PIN-kod 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="599"/>
        <source>Puk1</source>
        <translation>PUK-kod 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="600"/>
        <source>Puk2</source>
        <translation>PUK-kod 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="601"/>
        <source>Num SIM</source>
        <translation>SIM-nummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="604"/>
        <source>Manufacturer</source>
        <translation>Tillverkare</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="607"/>
        <location filename="../../eWallet.cpp" line="621"/>
        <source>Product</source>
        <translation>Produkt</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="608"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="609"/>
        <location filename="../../eWallet.cpp" line="622"/>
        <source>Serial #</source>
        <translation>Serienummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="611"/>
        <source>Company</source>
        <translation>Företag</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="612"/>
        <source>Date bought</source>
        <translation>Inköpsdatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="613"/>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="614"/>
        <location filename="../../eWallet.cpp" line="630"/>
        <source>Login</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="615"/>
        <source>Authorization key</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="616"/>
        <location filename="../../eWallet.cpp" line="625"/>
        <source>Price paid</source>
        <translation>Pris betalat</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="617"/>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="618"/>
        <location filename="../../eWallet.cpp" line="633"/>
        <source>Notes</source>
        <translation>Anteckningar</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="623"/>
        <source>Model #</source>
        <translation>Modellnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="624"/>
        <source>Bought from</source>
        <translation>Köpt från</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="626"/>
        <source>Guarantee period</source>
        <translation>Garantiperiod</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="632"/>
        <source>E mail used</source>
        <translation>E-post</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="640"/>
        <source>Social Security Number</source>
        <translation>Socialskyddssignum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="641"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="651"/>
        <source>Driver&apos;s License Number</source>
        <translation>Körkortsnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="652"/>
        <source>Date Issued</source>
        <translation>Utfärdat</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="909"/>
        <source>About</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="911"/>
        <source>Delete DB</source>
        <translation>Radera databas</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="913"/>
        <location filename="../../eWallet.cpp" line="924"/>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="916"/>
        <source>New</source>
        <translation>Nytt</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="918"/>
        <location filename="../../eWallet.cpp" line="1392"/>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="919"/>
        <source>Invert Sort</source>
        <translation>Sväng sortering</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="920"/>
        <source>Import</source>
        <translation>Importera</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="921"/>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="923"/>
        <source>Change Password</source>
        <translation>Ändra lösenord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="983"/>
        <source>Are you sure you want to remove it?</source>
        <translation>Är du säker på att du vill radera?</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1131"/>
        <source>Choose import file</source>
        <translation>Välj fil att importera från</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1133"/>
        <location filename="../../eWallet.cpp" line="1411"/>
        <source>Text files (*.txt);;</source>
        <translation>Textfiler (*.txt)</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1381"/>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1382"/>
        <location filename="../../eWallet.cpp" line="1395"/>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1391"/>
        <source>View</source>
        <translation>Granska</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1393"/>
        <source>New like this</source>
        <translation>Ny likadan</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1394"/>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1409"/>
        <source>Choose export file</source>
        <translation>Välj fil att exportera till</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1617"/>
        <source>About Wallet</source>
        <translation>Om Wallet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1617"/>
        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1656"/>
        <source>Changing password, please wait until application quits</source>
        <translation>Ändrar lösenord, vänligen vänta tills programmet avslutas</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1662"/>
        <source>Password changed successfully, application will exit</source>
        <translation>Lösenordet ändrat, programmet kommer att avslutas</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1664"/>
        <source>Password CANNOT BE changed, because %1, and application will exit</source>
        <translation>Lösenordet kan ej ändras och programmet kommer att avslutas. Fel: %1</translation>
    </message>
</context>
</TS>
